@@ -373,7 +373,8 @@ class InstallApplicationDataAndLinks(install_data):
         self.outfiles.extend( [item+'c' for item in self.outfiles if item.endswith('.py')] )
 
     def mkpath(self, name, mode=0o777):
-        return dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        return name
 
 ###########################################################################
 class InstallExecutableLinks(Command):
@@ -415,7 +416,8 @@ class InstallExecutableLinks(Command):
         return self.outfiles or []
 
     def mkpath(self, name, mode=0o777):
-        return dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        return name
 
 ###########################################################################
 # Fix the --root option for the install_lib command.
@@ -1124,7 +1126,8 @@ class InstallKControlModule(Command):
         return self.outfiles or []
 
     def mkpath(self, name, mode=0o777):
-        return dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        return name
 
 ###########################################################################
 class BuildDocbookHTML(Command):
@@ -1243,7 +1246,8 @@ class InstallDocbookHTML(Command):
         return self.outfiles or []
 
     def mkpath(self, name, mode=0o777):
-        return dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        return name
 
 ###########################################################################
 class UpdateI18NMessages(Command):
@@ -1434,7 +1438,8 @@ class InstallI18NMessages(Command):
         return self.outfiles
 
     def mkpath(self, name, mode=0o777):
-        return dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        return name
 
 
 ###########################################################################
@@ -2005,7 +2010,8 @@ class InstallTdeioslave(Command):
         return self.outfiles or []
 
     def mkpath(self, name, mode=0o777):
-        return dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        dir_util.mkpath(name, mode, dry_run=self.dry_run)
+        return name
 
 ###########################################################################
 class CheckPyTQt(Command):
